
From: Stas Sergeev <stsp@aknet.ru>

The attached patch moves the IRQ-related SA_xxx flags (namely, SA_PROBE,
SA_SAMPLE_RANDOM and SA_SHIRQ) from all the arch-specific headers to
linux/signal.h.  This looks like a left-over after the irq-handling code
was consolidated.  The code was moved to kernel/irq/*, but the flags are
still left per-arch.

Right now, adding a new IRQ flag to the arch-specific header, like this
patch does:
http://cvs.sourceforge.net/viewcvs.py/*checkout*/alsa/alsa-driver/utils/patches/pcsp-kernel-2.6.10-03.diff?rev=1.1
no longer works, it breaks the compilation for all other arches, unless you
add that flag to all the other arch-specific headers too.  So I think such
a clean-up makes sense.

Signed-off-by: Stas Sergeev <stsp@aknet.ru>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/asm-alpha/signal.h     |   14 --------------
 25-akpm/include/asm-arm/signal.h       |   11 -----------
 25-akpm/include/asm-arm26/signal.h     |   11 -----------
 25-akpm/include/asm-cris/signal.h      |   14 --------------
 25-akpm/include/asm-frv/signal.h       |   14 --------------
 25-akpm/include/asm-h8300/signal.h     |   13 -------------
 25-akpm/include/asm-i386/signal.h      |   14 --------------
 25-akpm/include/asm-ia64/signal.h      |   10 ----------
 25-akpm/include/asm-m32r/signal.h      |   14 --------------
 25-akpm/include/asm-m68k/signal.h      |   13 -------------
 25-akpm/include/asm-m68knommu/signal.h |   13 -------------
 25-akpm/include/asm-mips/signal.h      |   15 ---------------
 25-akpm/include/asm-parisc/signal.h    |   11 -----------
 25-akpm/include/asm-ppc/signal.h       |   13 -------------
 25-akpm/include/asm-ppc64/signal.h     |   13 -------------
 25-akpm/include/asm-s390/signal.h      |   14 --------------
 25-akpm/include/asm-sh/signal.h        |   14 --------------
 25-akpm/include/asm-sh64/signal.h      |   14 --------------
 25-akpm/include/asm-sparc/signal.h     |    8 --------
 25-akpm/include/asm-sparc64/signal.h   |    8 --------
 25-akpm/include/asm-v850/signal.h      |   15 ---------------
 25-akpm/include/asm-x86_64/signal.h    |   14 --------------
 25-akpm/include/linux/signal.h         |   11 +++++++++++
 23 files changed, 11 insertions(+), 280 deletions(-)

diff -puN include/asm-alpha/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-alpha/signal.h
--- 25/include/asm-alpha/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-alpha/signal.h	Fri Apr  1 13:31:57 2005
@@ -109,20 +109,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	4096
 #define SIGSTKSZ	16384
 
-
-#ifdef __KERNEL__
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x40000000
-#endif
-
 #define SIG_BLOCK          1	/* for blocking signals */
 #define SIG_UNBLOCK        2	/* for unblocking signals */
 #define SIG_SETMASK        3	/* for setting the signal mask */
diff -puN include/asm-arm26/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-arm26/signal.h
--- 25/include/asm-arm26/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-arm26/signal.h	Fri Apr  1 13:31:57 2005
@@ -114,18 +114,7 @@ typedef unsigned long sigset_t;
 #define SIGSTKSZ	8192
 
 #ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		0x80000000
-#define SA_SAMPLE_RANDOM	0x10000000
 #define SA_IRQNOMASK		0x08000000
-#define SA_SHIRQ		0x04000000
 #endif
 
 #define SIG_BLOCK          0	/* for blocking signals */
diff -puN include/asm-arm/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-arm/signal.h
--- 25/include/asm-arm/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-arm/signal.h	Fri Apr  1 13:31:57 2005
@@ -114,18 +114,7 @@ typedef unsigned long sigset_t;
 #define SIGSTKSZ	8192
 
 #ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		0x80000000
-#define SA_SAMPLE_RANDOM	0x10000000
 #define SA_IRQNOMASK		0x08000000
-#define SA_SHIRQ		0x04000000
 #endif
 
 #define SIG_BLOCK          0	/* for blocking signals */
diff -puN include/asm-cris/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-cris/signal.h
--- 25/include/asm-cris/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-cris/signal.h	Fri Apr  1 13:31:57 2005
@@ -108,20 +108,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-frv/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-frv/signal.h
--- 25/include/asm-frv/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-frv/signal.h	Fri Apr  1 13:31:57 2005
@@ -107,20 +107,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-h8300/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-h8300/signal.h
--- 25/include/asm-h8300/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-h8300/signal.h	Fri Apr  1 13:31:57 2005
@@ -107,19 +107,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-i386/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-i386/signal.h
--- 25/include/asm-i386/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-i386/signal.h	Fri Apr  1 13:31:57 2005
@@ -110,20 +110,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-ia64/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-ia64/signal.h
--- 25/include/asm-ia64/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-ia64/signal.h	Fri Apr  1 13:31:57 2005
@@ -114,16 +114,6 @@
 #define _NSIG_BPW	64
 #define _NSIG_WORDS	(_NSIG / _NSIG_BPW)
 
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
 #define SA_PERCPU_IRQ		0x02000000
 
 #endif /* __KERNEL__ */
diff -puN include/asm-m32r/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-m32r/signal.h
--- 25/include/asm-m32r/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-m32r/signal.h	Fri Apr  1 13:31:57 2005
@@ -114,20 +114,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-m68knommu/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-m68knommu/signal.h
--- 25/include/asm-m68knommu/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-m68knommu/signal.h	Fri Apr  1 13:31:57 2005
@@ -105,19 +105,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-m68k/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-m68k/signal.h
--- 25/include/asm-m68k/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-m68k/signal.h	Fri Apr  1 13:31:57 2005
@@ -105,19 +105,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-mips/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-mips/signal.h
--- 25/include/asm-mips/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-mips/signal.h	Fri Apr  1 13:31:57 2005
@@ -98,21 +98,6 @@ typedef unsigned long old_sigset_t;		/* 
 #define MINSIGSTKSZ    2048
 #define SIGSTKSZ       8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ flag is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x02000000
-
-#endif /* __KERNEL__ */
-
 #define SIG_BLOCK	1	/* for blocking signals */
 #define SIG_UNBLOCK	2	/* for unblocking signals */
 #define SIG_SETMASK	3	/* for setting the signal mask */
diff -puN include/asm-parisc/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-parisc/signal.h
--- 25/include/asm-parisc/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-parisc/signal.h	Fri Apr  1 13:31:57 2005
@@ -89,17 +89,6 @@
 #define _NSIG_BPW	BITS_PER_LONG
 #define _NSIG_WORDS	(_NSIG / _NSIG_BPW)
 
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-
 #endif /* __KERNEL__ */
 
 #define SIG_BLOCK          0	/* for blocking signals */
diff -puN include/asm-ppc64/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-ppc64/signal.h
--- 25/include/asm-ppc64/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-ppc64/signal.h	Fri Apr  1 13:31:57 2005
@@ -96,19 +96,6 @@ typedef struct {
 
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
 
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
diff -puN include/asm-ppc/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-ppc/signal.h
--- 25/include/asm-ppc/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-ppc/signal.h	Fri Apr  1 13:31:57 2005
@@ -99,19 +99,6 @@ typedef struct {
 
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif /* __KERNEL__ */
 
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
diff -puN include/asm-s390/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-s390/signal.h
--- 25/include/asm-s390/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-s390/signal.h	Fri Apr  1 13:31:57 2005
@@ -117,20 +117,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ     2048
 #define SIGSTKSZ        8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE                SA_ONESHOT
-#define SA_SAMPLE_RANDOM        SA_RESTART
-#define SA_SHIRQ                0x04000000
-#endif
-
 #define SIG_BLOCK          0    /* for blocking signals */
 #define SIG_UNBLOCK        1    /* for unblocking signals */
 #define SIG_SETMASK        2    /* for setting the signal mask */
diff -puN include/asm-sh64/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-sh64/signal.h
--- 25/include/asm-sh64/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-sh64/signal.h	Fri Apr  1 13:31:57 2005
@@ -107,20 +107,6 @@ typedef struct {
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	THREAD_SIZE
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-sh/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-sh/signal.h
--- 25/include/asm-sh/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-sh/signal.h	Fri Apr  1 13:31:57 2005
@@ -108,20 +108,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-sparc64/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-sparc64/signal.h
--- 25/include/asm-sparc64/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-sparc64/signal.h	Fri Apr  1 13:31:57 2005
@@ -145,7 +145,6 @@ struct sigstack {
 #define SA_ONESHOT	_SV_RESET
 #define SA_INTERRUPT	0x10u
 #define SA_NOMASK	0x20u
-#define SA_SHIRQ	0x40u
 #define SA_NOCLDWAIT    0x100u
 #define SA_SIGINFO      0x200u
 
@@ -165,11 +164,6 @@ struct sigstack {
 
 #ifdef __KERNEL__
 /*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- *
  * DJHR
  * SA_STATIC_ALLOC is used for the SPARC system to indicate that this
  * interrupt handler's irq structure should be statically allocated
@@ -180,8 +174,6 @@ struct sigstack {
  * statically allocated data.. which is NOT GOOD.
  *
  */
-#define SA_PROBE SA_ONESHOT
-#define SA_SAMPLE_RANDOM SA_RESTART
 #define SA_STATIC_ALLOC		0x80
 #endif
 
diff -puN include/asm-sparc/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-sparc/signal.h
--- 25/include/asm-sparc/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-sparc/signal.h	Fri Apr  1 13:31:57 2005
@@ -143,7 +143,6 @@ struct sigstack {
 #define SA_ONESHOT	_SV_RESET
 #define SA_INTERRUPT	0x10u
 #define SA_NOMASK	0x20u
-#define SA_SHIRQ	0x40u
 #define SA_NOCLDWAIT	0x100u
 #define SA_SIGINFO	0x200u
 
@@ -162,11 +161,6 @@ struct sigstack {
 
 #ifdef __KERNEL__
 /*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- *
  * DJHR
  * SA_STATIC_ALLOC is used for the SPARC system to indicate that this
  * interrupt handler's irq structure should be statically allocated
@@ -177,8 +171,6 @@ struct sigstack {
  * statically allocated data.. which is NOT GOOD.
  *
  */
-#define SA_PROBE SA_ONESHOT
-#define SA_SAMPLE_RANDOM SA_RESTART
 #define SA_STATIC_ALLOC		0x80
 #endif
 
diff -puN include/asm-v850/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-v850/signal.h
--- 25/include/asm-v850/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-v850/signal.h	Fri Apr  1 13:31:57 2005
@@ -110,21 +110,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-
-#ifdef __KERNEL__
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif /* __KERNEL__ */
-
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/asm-x86_64/signal.h~move-sa_xxx-defines-to-linux-signalh include/asm-x86_64/signal.h
--- 25/include/asm-x86_64/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/asm-x86_64/signal.h	Fri Apr  1 13:31:57 2005
@@ -116,20 +116,6 @@ typedef unsigned long sigset_t;
 #define MINSIGSTKSZ	2048
 #define SIGSTKSZ	8192
 
-#ifdef __KERNEL__
-
-/*
- * These values of sa_flags are used only by the kernel as part of the
- * irq handling routines.
- *
- * SA_INTERRUPT is also used by the irq handling routines.
- * SA_SHIRQ is for shared interrupt support on PCI and EISA.
- */
-#define SA_PROBE		SA_ONESHOT
-#define SA_SAMPLE_RANDOM	SA_RESTART
-#define SA_SHIRQ		0x04000000
-#endif
-
 #define SIG_BLOCK          0	/* for blocking signals */
 #define SIG_UNBLOCK        1	/* for unblocking signals */
 #define SIG_SETMASK        2	/* for setting the signal mask */
diff -puN include/linux/signal.h~move-sa_xxx-defines-to-linux-signalh include/linux/signal.h
--- 25/include/linux/signal.h~move-sa_xxx-defines-to-linux-signalh	Fri Apr  1 13:31:57 2005
+++ 25-akpm/include/linux/signal.h	Fri Apr  1 13:31:57 2005
@@ -9,6 +9,17 @@
 #ifdef __KERNEL__
 
 /*
+ * These values of sa_flags are used only by the kernel as part of the
+ * irq handling routines.
+ *
+ * SA_INTERRUPT is also used by the irq handling routines.
+ * SA_SHIRQ is for shared interrupt support on PCI and EISA.
+ */
+#define SA_PROBE		SA_ONESHOT
+#define SA_SAMPLE_RANDOM	SA_RESTART
+#define SA_SHIRQ		0x04000000
+
+/*
  * Real Time signals may be queued.
  */
 
_
